==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/sv.js <==
﻿/*
 * PLUGIN RSS
 *
 * Swedish language file.
 *
 * Author: Magnus Holm	(holmen@brasse.se)
 */

 theUILang.addRSS			= "Lägg till RSS-flöde";
 theUILang.feedURL			= "Flödesaddress";
 theUILang.alias			= "Anpassat alias";
 theUILang.rssAuto			= "Ladda automatiskt ner artiklar i flöde";
 theUILang.allFeeds			= "Alla flöden";
 theUILang.incorrectURL 		= "Ange korrekt flödesaddress."
 theUILang.cantFetchRSS 		= "Fel vid laddning av flöde.";
 theUILang.rssAlreadyExist		= "Flödet existerar redan.";
 theUILang.rssDontExist 		= "Flödet exsterar inte.";
 theUILang.rssCantLoadTorrent		= "Fel vid laddning av torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Redan laddad";
 theUILang.rssMenuLoad			= "Ladda";
 theUILang.rssMenuOpen			= "Öppna i webbläsare";
 theUILang.rssMenuClearHistory		= "Töm historik";
 theUILang.rssMenuAddToFilter		= "Lägg till i favoriter";
 theUILang.rssMenuManager		= "RSS-hanterare";
 theUILang.rssMenuRefresh		= "Uppdatera flöde";
 theUILang.rssMenuDisable		= "Inaktivera flöde";
 theUILang.rssMenuEnable		= "Aktivera flöde";
 theUILang.rssMenuEdit			= "Redigera flöde";
 theUILang.rssMenuDelete		= "Ta bort flöde";
 theUILang.rssDeletePrompt		= "Vill du verkligen ta bort markerat flöde?";
 theUILang.rssNewFilter 		= "Nytt filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter 		= "Lägg till";
 theUILang.rssDelFilter 		= "Ta bort";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filterinställningar";
 theUILang.rssIncorrectFilter		= "Felaktigt filter.";
 theUILang.foundedByFilter		= "Matchningar";
 theUILang.rssExclude			= "Exkludera";
 theUILang.rssStatusError		= "Laddningsfel";
 theUILang.rssFeeds			= "Flöden";
 theUILang.rssCheckTitle		= "Kontrollera titelfält";
 theUILang.rssCheckDescription		= "Kontrollera beskrivningsfält";
 theUILang.rssCheckLink 		= "Kontrollera länkfält";
 theUILang.rssMinInterval		= "Min intervall";
 theUILang.rssIntervalAlways		= "(matcha alltid)";
 theUILang.rssIntervalOnce		= "(matcha endast en gång)";
 theUILang.rssInterval12h		= "12 timmar";
 theUILang.rssInterval1d		= "1 dag";
 theUILang.rssInterval2d		= "2 dagar";
 theUILang.rssInterval3d		= "3 dagar";
 theUILang.rssInterval4d		= "4 dagar";
 theUILang.rssInterval6d		= "6 dagar";
 theUILang.rssInterval1w		= "1 vecka";
 theUILang.rssInterval2w		= "2 veckor";
 theUILang.rssInterval3w		= "3 veckor";
 theUILang.rssInterval1m		= "1 månad";
 theUILang.rssClearFilter		= "Återställ";
 theUILang.rssMarkAs			= "Markera som";
 theUILang.rssAsLoaded			= "laddad";
 theUILang.rssAsUnloaded		= "urladdad";
 theUILang.addRSSGroup			= "Lägg till RSS-grupp";
 theUILang.editRSSGroup 		= "Redigera RSS-grupp";
 theUILang.addRSSGroupContent		= "Innehåll";
 theUILang.rssMenuGroupDisable		= "Inaktivera grupp";
 theUILang.rssMenuGroupRefresh		= "Uppdatera grupp";
 theUILang.rssMenuGroupEnable		= "Aktivera grupp";
 theUILang.rssMenuGroupEdit		= "Redigera grupp";
 theUILang.rssMenuGroupDelete		= "Ta bort grupp";
 theUILang.rssMenuGroupContentsDelete	= "Radera innehåll";
 theUILang.rssDeleteGroupPrompt 	= "Vill du verkligen ta bort markerad grupp?";
 theUILang.rssDeleteGroupContentsPrompt = "Vill du verkligen ta bort markerad grupp och radera allt innehåll?";
 theUILang.rssAllFiters 		= "Alla filter";
 theUILang.rssUpdateInterval 		= "Uppdateringsintervall";
 theUILang.Directories			= "Mappar";
 theUILang.Labels			= "Etiketter";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/plugins/rss/lang/sv.js <==
﻿/*
 * PLUGIN RSS
 *
 * Swedish language file.
 *
 * Author: Magnus Holm	(holmen@brasse.se)
 */

 theUILang.addRSS			= "Lägg till RSS-flöde";
 theUILang.feedURL			= "Flödesaddress";
 theUILang.alias			= "Anpassat alias";
 theUILang.rssAuto			= "Ladda automatiskt ner artiklar i flöde";
 theUILang.allFeeds			= "Alla flöden";
 theUILang.incorrectURL			= "Ange korrekt flödesaddress.";
 theUILang.cantFetchRSS			= "Fel vid laddning av flöde.";
 theUILang.rssAlreadyExist		= "Flödet existerar redan.";
 theUILang.rssDontExist			= "Flödet exsterar inte.";
 theUILang.rssCantLoadTorrent		= "Fel vid laddning av torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Redan laddad";
 theUILang.rssMenuLoad			= "Ladda";
 theUILang.rssMenuOpen			= "Öppna i webbläsare";
 theUILang.rssMenuClearHistory		= "Töm historik";
 theUILang.rssMenuAddToFilter		= "Lägg till i favoriter";
 theUILang.rssMenuManager		= "RSS-hanterare";
 theUILang.rssMenuRefresh		= "Uppdatera flöde";
 theUILang.rssMenuDisable		= "Inaktivera flöde";
 theUILang.rssMenuEnable		= "Aktivera flöde";
 theUILang.rssMenuEdit			= "Redigera flöde";
 theUILang.rssMenuDelete		= "Ta bort flöde";
 theUILang.rssDeletePrompt		= "Vill du verkligen ta bort markerat flöde?";
 theUILang.rssNewFilter			= "Nytt filter";
 theUILang.rssFilter			= "Filter";
 theUILang.rssAddFilter			= "Lägg till";
 theUILang.rssDelFilter			= "Ta bort";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Filterinställningar";
 theUILang.rssIncorrectFilter		= "Felaktigt filter.";
 theUILang.foundedByFilter		= "Matchningar";
 theUILang.rssExclude			= "Exkludera";
 theUILang.rssStatusError		= "Laddningsfel";
 theUILang.rssFeeds			= "Flöden";
 theUILang.rssCheckTitle		= "Kontrollera titelfält";
 theUILang.rssCheckDescription		= "Kontrollera beskrivningsfält";
 theUILang.rssCheckLink			= "Kontrollera länkfält";
 theUILang.rssMinInterval		= "Min intervall";
 theUILang.rssIntervalAlways		= "(matcha alltid)";
 theUILang.rssIntervalOnce		= "(matcha endast en gång)";
 theUILang.rssInterval12h		= "12 timmar";
 theUILang.rssInterval1d		= "1 dag";
 theUILang.rssInterval2d		= "2 dagar";
 theUILang.rssInterval3d		= "3 dagar";
 theUILang.rssInterval4d		= "4 dagar";
 theUILang.rssInterval6d		= "6 dagar";
 theUILang.rssInterval1w		= "1 vecka";
 theUILang.rssInterval2w		= "2 veckor";
 theUILang.rssInterval3w		= "3 veckor";
 theUILang.rssInterval1m		= "1 månad";
 theUILang.rssClearFilter		= "Återställ";
 theUILang.rssMarkAs			= "Markera som";
 theUILang.rssAsLoaded			= "laddad";
 theUILang.rssAsUnloaded		= "urladdad";
 theUILang.addRSSGroup			= "Lägg till RSS-grupp";
 theUILang.editRSSGroup			= "Redigera RSS-grupp";
 theUILang.addRSSGroupContent		= "Innehåll";
 theUILang.rssMenuGroupDisable		= "Inaktivera grupp";
 theUILang.rssMenuGroupRefresh		= "Uppdatera grupp";
 theUILang.rssMenuGroupEnable		= "Aktivera grupp";
 theUILang.rssMenuGroupEdit		= "Redigera grupp";
 theUILang.rssMenuGroupDelete		= "Ta bort grupp";
 theUILang.rssMenuGroupContentsDelete	= "Radera innehåll";
 theUILang.rssDeleteGroupPrompt		= "Vill du verkligen ta bort markerad grupp?";
 theUILang.rssDeleteGroupContentsPrompt	= "Vill du verkligen ta bort markerad grupp och radera allt innehåll?";
 theUILang.rssAllFiters			= "Alla filter";
 theUILang.rssUpdateInterval		= "Uppdateringsintervall";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Mappar";
 theUILang.Labels			= "Etiketter";

thePlugins.get("rss").langLoaded();
